=== modified file 'breezy/git/config.py'
--- breezy/git/config.py	2020-03-21 22:11:40 +0000
+++ breezy/git/config.py	2020-03-21 23:20:27 +0000
@@ -63,6 +63,12 @@
             except KeyError:
                 return email.decode()
             return '%s <%s>' % (name.decode(), email.decode())
+        if name == 'gpg_signing_key':
+            try:
+                key = self._config.get((b'user', ), b'signingkey')
+            except KeyError:
+                return None
+            return key.decode()
         return None
 
 

=== modified file 'breezy/git/tests/test_blackbox.py'
--- breezy/git/tests/test_blackbox.py	2020-03-21 16:59:13 +0000
+++ breezy/git/tests/test_blackbox.py	2020-03-21 20:56:33 +0000
@@ -445,6 +445,18 @@
         self.assertEqual(out, "some@example.com\n")
         self.assertEqual(err, "")
 
+    def test_local_signing_key(self):
+        r = GitRepo.init("gitr", mkdir=True)
+        self.build_tree_contents([('gitr/.git/config', """\
+[user]
+  email = some@example.com
+  name = Test User
+  signingkey = D729A457
+""")])
+        out, err = self.run_bzr(["config", "-d", "gitr", "gpg_signing_key"])
+        self.assertEqual(out, "D729A457\n")
+        self.assertEqual(err, "")
+
 
 class ShallowTests(ExternalBase):
 

=== modified file 'doc/en/release-notes/brz-3.1.txt'
--- doc/en/release-notes/brz-3.1.txt	2020-03-21 16:59:13 +0000
+++ doc/en/release-notes/brz-3.1.txt	2020-03-21 20:56:33 +0000
@@ -115,7 +115,7 @@
    (Jelmer Vernooĳ)
 
  * ``.git/config`` is now consulted to determine the users' identity
-   for commits. (Jelmer Vernooĳ)
+   for commits, and the gpg_signing_key. (Jelmer Vernooĳ)
 
 Bug Fixes
 *********

